@@ -4,6 +4,7 @@ const {
   Symbol,
   SymbolAsyncIterator,
   SymbolIterator,
+  SymbolFor,
 } = primordials;
 
 const kDestroyed = Symbol('kDestroyed');
@@ -11,6 +12,8 @@ const kIsErrored = Symbol('kIsErrored');
 const kIsReadable = Symbol('kIsReadable');
 const kIsDisturbed = Symbol('kIsDisturbed');
 
+const kIsClosedPromise = SymbolFor('nodejs.webstream.isClosedPromise');
+
 function isReadableNodeStream(obj, strict = false) {
   return !!(
     obj &&
@@ -55,6 +58,25 @@ function isNodeStream(obj) {
   );
 }
 
+function isReadableStream(obj) {
+  return !!(
+    obj &&
+    !isNodeStream(obj) &&
+    typeof obj.pipeThrough === 'function' &&
+    typeof obj.getReader === 'function' &&
+    typeof obj.cancel === 'function'
+  );
+}
+
+function isWritableStream(obj) {
+  return !!(
+    obj &&
+    !isNodeStream(obj) &&
+    typeof obj.getWriter === 'function' &&
+    typeof obj.abort === 'function'
+  );
+}
+
 function isIterable(obj, isAsync) {
   if (obj == null) return false;
   if (isAsync === true) return typeof obj[SymbolAsyncIterator] === 'function';
@@ -118,17 +140,19 @@ function isReadableFinished(stream, strict) {
 
 function isReadable(stream) {
   if (stream && stream[kIsReadable] != null) return stream[kIsReadable];
-  const r = isReadableNodeStream(stream);
   if (typeof stream?.readable !== 'boolean') return null;
   if (isDestroyed(stream)) return false;
-  return r && stream.readable && !isReadableFinished(stream);
+  return isReadableNodeStream(stream) &&
+    stream.readable &&
+    !isReadableFinished(stream);
 }
 
 function isWritable(stream) {
-  const r = isWritableNodeStream(stream);
   if (typeof stream?.writable !== 'boolean') return null;
   if (isDestroyed(stream)) return false;
-  return r && stream.writable && !isWritableEnded(stream);
+  return isWritableNodeStream(stream) &&
+    stream.writable &&
+    !isWritableEnded(stream);
 }
 
 function isFinished(stream, opts) {
@@ -151,11 +175,39 @@ function isFinished(stream, opts) {
   return true;
 }
 
+function isWritableErrored(stream) {
+  if (!isNodeStream(stream)) {
+    return null;
+  }
+
+  if (stream.writableErrored) {
+    return stream.writableErrored;
+  }
+
+  return stream._writableState?.errored ?? null;
+}
+
+function isReadableErrored(stream) {
+  if (!isNodeStream(stream)) {
+    return null;
+  }
+
+  if (stream.readableErrored) {
+    return stream.readableErrored;
+  }
+
+  return stream._readableState?.errored ?? null;
+}
+
 function isClosed(stream) {
   if (!isNodeStream(stream)) {
     return null;
   }
 
+  if (typeof stream.closed === 'boolean') {
+    return stream.closed;
+  }
+
   const wState = stream._writableState;
   const rState = stream._readableState;
 
@@ -239,19 +291,24 @@ module.exports = {
   kIsErrored,
   isReadable,
   kIsReadable,
+  kIsClosedPromise,
   isClosed,
   isDestroyed,
   isDuplexNodeStream,
   isFinished,
   isIterable,
   isReadableNodeStream,
+  isReadableStream,
   isReadableEnded,
   isReadableFinished,
+  isReadableErrored,
   isNodeStream,
   isWritable,
   isWritableNodeStream,
+  isWritableStream,
   isWritableEnded,
   isWritableFinished,
+  isWritableErrored,
   isServerRequest,
   isServerResponse,
   willEmitClose,
