@@ -23,6 +23,7 @@ const {
   StringPrototypeCharCodeAt,
   StringPrototypeIncludes,
   StringPrototypeReplace,
+  StringPrototypeReplaceAll,
   StringPrototypeSlice,
   StringPrototypeSplit,
   StringPrototypeStartsWith,
@@ -530,10 +531,11 @@ ObjectDefineProperties(URLSearchParams.prototype, {
   keys: kEnumerableProperty,
   values: kEnumerableProperty,
   toString: kEnumerableProperty,
-  [SymbolToStringTag]: { configurable: true, value: 'URLSearchParams' },
+  [SymbolToStringTag]: { __proto__: null, configurable: true, value: 'URLSearchParams' },
 
   // https://heycam.github.io/webidl/#es-iterable-entries
   [SymbolIterator]: {
+    __proto__: null,
     configurable: true,
     writable: true,
     value: URLSearchParams.prototype.entries,
@@ -746,13 +748,13 @@ class URL {
   toString() {
     if (!isURLThis(this))
       throw new ERR_INVALID_THIS('URL');
-    return this[kFormat]({});
+    return this[kFormat]();
   }
 
   get href() {
     if (!isURLThis(this))
       throw new ERR_INVALID_THIS('URL');
-    return this[kFormat]({});
+    return this[kFormat]();
   }
 
   set href(input) {
@@ -1009,7 +1011,7 @@ class URL {
   toJSON() {
     if (!isURLThis(this))
       throw new ERR_INVALID_THIS('URL');
-    return this[kFormat]({});
+    return this[kFormat]();
   }
 
   static createObjectURL(obj) {
@@ -1045,8 +1047,8 @@ class URL {
 }
 
 ObjectDefineProperties(URL.prototype, {
-  [kFormat]: { configurable: false, writable: false },
-  [SymbolToStringTag]: { configurable: true, value: 'URL' },
+  [kFormat]: { __proto__: null, configurable: false, writable: false },
+  [SymbolToStringTag]: { __proto__: null, configurable: true, value: 'URL' },
   toString: kEnumerableProperty,
   href: kEnumerableProperty,
   origin: kEnumerableProperty,
@@ -1063,6 +1065,11 @@ ObjectDefineProperties(URL.prototype, {
   toJSON: kEnumerableProperty,
 });
 
+ObjectDefineProperties(URL, {
+  createObjectURL: kEnumerableProperty,
+  revokeObjectURL: kEnumerableProperty,
+});
+
 function update(url, params) {
   if (!url)
     return;
@@ -1229,6 +1236,7 @@ function serializeParams(array) {
 function defineIDLClass(proto, classStr, obj) {
   // https://heycam.github.io/webidl/#dfn-class-string
   ObjectDefineProperty(proto, SymbolToStringTag, {
+    __proto__: null,
     writable: false,
     enumerable: false,
     configurable: true,
@@ -1238,6 +1246,7 @@ function defineIDLClass(proto, classStr, obj) {
   // https://heycam.github.io/webidl/#es-operations
   for (const key of ObjectKeys(obj)) {
     ObjectDefineProperty(proto, key, {
+      __proto__: null,
       writable: true,
       enumerable: true,
       configurable: true,
@@ -1246,6 +1255,7 @@ function defineIDLClass(proto, classStr, obj) {
   }
   for (const key of ObjectGetOwnPropertySymbols(obj)) {
     ObjectDefineProperty(proto, key, {
+      __proto__: null,
       writable: true,
       enumerable: false,
       configurable: true,
@@ -1420,8 +1430,6 @@ function urlToHttpOptions(url) {
   return options;
 }
 
-const forwardSlashRegEx = /\//g;
-
 function getPathFromURLWin32(url) {
   const hostname = url.hostname;
   let pathname = url.pathname;
@@ -1436,7 +1444,7 @@ function getPathFromURLWin32(url) {
       }
     }
   }
-  pathname = pathname.replace(forwardSlashRegEx, '\\');
+  pathname = StringPrototypeReplaceAll(pathname, '/', '\\');
   pathname = decodeURIComponent(pathname);
   if (hostname !== '') {
     // If hostname is set, then we have a UNC path
